function [ T ] = simplexiter( tableau )
%performs the simplex iterations on a given tableau
%
%inputs:
%   tableau ... [A:I:b;z], where A and I can be mixed up
%
%output:
%   T       ... solution using the simplex steps

  T = tableau;
  m = size(T,1)-1;
  n = size(T,2)-1;
  
  % find basic and non basic variable indices according to I-structure
  basic = []; non_basic = [];
  for i=1:n
     current_col = T(1:m,i);
     if sum(current_col==1)==1 && sum(current_col==0)==m-1 
         basic = [basic,i];
     else
         non_basic = [non_basic,i];
     end
  end
  
  % normalize z-row
  for j=1:m
      coeff = T(m+1,basic(j));
      if coeff~=0
        T(m+1,:) = T(m+1,:)-coeff*T(j,:);    
      end   
  end

  % perform simplex iterations
  while min(T(m+1,non_basic)) < 0 
      
      % find leaving variable
      [~,s] = min(T(m+1,non_basic));
      s = non_basic(s);
      
      % find entering variable
      pos_vars = T(1:m,s); pos_vars(pos_vars<=0) = NaN;
      [~,r] = min(T(1:m,n+1)./pos_vars);
      
      % update basic variable indices (subst. s with r)
      non_basic(non_basic==s)=basic(r);
      basic(r) = s;
      
      % perform pivot operations (gauss-jordan)
      T(r,:) = T(r,:)./T(r,s);
      for j = [1:r-1,r+1:m+1]
          T(j,:) = T(j,:) - T(j,s)*T(r,:);
      end
      
  end  
end